@@ -340,12 +340,11 @@ static bool get_proc_stat(char *pid, char *format_str, struct procstat* prs,
     if(comm_len > comm_esize) {
       comm_len = comm_esize;
     }
-    if(comm_len == 0) {
-      goto done;
+    if(comm_len > 0) {
+      strncpy(prs->comm, open_paren + 1, comm_esize);
+      prs->comm[comm_esize] = '\0';
     }
 
-    strncpy(prs->comm, open_paren + 1, comm_esize);
-    prs->comm[comm_esize] = '\0';
 
     /* address at which we pickup again, after the ')'
      * NOTE: we don't bother checking bounds since strchr didn't return NULL
